use 5.8.0; # for utf8
use ExtUtils::MakeMaker;
use FindBin qw( $Bin );
use strict;
use warnings;

## Create a Ockham::Alert::Config file for configuration stuff 
if ( ! -f 'lib/Ockham/Alert/Config.pm' ) { writeConfig(); } 
else { print "using existing Ockham::Alert::Config in lib directory\n"; }

## create the Makefile
WriteMakefile(
    'NAME'		=> 'Ockham-Alert',
    'DISTNAME'		=> 'Ockham-Alert',
    'ABSTRACT'		=> 'An current awareness tool for OAI-PMH repositories',
    'VERSION_FROM'	=> 'lib/Ockham/Alert/DB.pm', 
    'PMLIBDIRS'		=> [ qw( lib/ ) ],
    'AUTHOR'		=> 'Ed Summers <ehs@pobox.com>',
    'PREREQ_PM'		=> { 
                            'Net::OAI::Harvester'       => '0.95',
                            'DateTime'                  => 0,
                            'Class::DBI'                => 0,
                            'DBD::SQLite'               => 0,
                            'MARC::Record'              => '1.34',
			    },
    EXE_FILES		=> [ 
			    'bin/ockham-harvest',
			   ],
);

## verify db looks good
checkDB();

## subroutines

sub writeConfig {
    my $DB_DRIVER = question( 
        'What database driver will you be using',
        'Pg' 
    );
    my $DB_NAME = question( 
        'What is the name of your database',
        'ockham' 
    );
    my $DB_USERNAME = question( 
        'What is the database username',
        ''
    );
    my $DB_PASSWORD = question( 
        'What is the database password',
        ''
    );
    my $SWISH = question(
        'Where does the swish-e executable live',
        '/usr/local/bin/swish-e'
    );
    my $SWISH_INDEX = question(
        'Where should swish-e store the index',
        '/home/ed/dev/ockham/alert/db/swish/alert'
    );
    my $PLUCENE_INDEX = question(
        'What directory can plucene use for index files',
        '/home/ed/dev/ockham/alert/db/plucene'
    );

    open( CONFIG,  ">lib/Ockham/Alert/Config.pm" );
    print CONFIG
    
<<"CONFIG_SOURCE";
package Ockham::Alert::Config;

use strict;
use warnings;
use base qw( Exporter );
our \@EXPORT_OK = qw( 
    DB_DRIVER 
    DB_NAME 
    DB_DSN
    DB_USERNAME
    DB_PASSWORD
    SWISH
    SWISH_INDEX
    PLUCENE_INDEX
);

use constant DB_DRIVER   => '$DB_DRIVER';
use constant DB_NAME     => '$DB_NAME';
use constant DB_DSN      => 'dbi:'.DB_DRIVER.':dbname='.DB_NAME;
use constant DB_USERNAME => '$DB_USERNAME';
use constant DB_PASSWORD => '$DB_PASSWORD';
use constant SWISH       => '$SWISH';
use constant SWISH_INDEX => '$SWISH_INDEX';
use constant PLUCENE_INDEX => '$PLUCENE_INDEX';

1;

CONFIG_SOURCE

    close( CONFIG );
}


sub question { 
    my ( $question, $default ) = @_;
    print "$question [$default] : ";
    my $answer = <STDIN>;
    chomp( $answer );
    $answer = $default if ! $answer;
    return( $answer );
}


## checks that we can connect to the db and that the schema looks ok

sub checkDB {

    eval( q(
        use lib "lib";
        use Ockham::Alert::DB;
        my $dbh = Ockham::Alert::DB->db_Main();  
        my $sth = $dbh->prepare( "select * from resource" );
        $sth->execute();
    ) );

    return unless $@;
    print 

<<DB_WARNING;

***
*** You need to create your database using the appropriate
*** schema file in the db subdirectory. 'make test' will fail miserably 
*** until you do so. 
***
*** If you need to adjust your db settings you can edit
*** them in lib/Ockham/Alert/Config.pm.
***

DB_WARNING

}



