#!/usr/bin/perl


# Eric Lease Morgan <emorgan@nd.edu>
# August 4, 2004 - first hack


=head1 NAME

swish-search.pl - search an OCKHAM swish-e index

=head1 SYNOPSIS

    % ./swish-search.pl title=barn

=head1 DESCRIPTION

Use this script to search the swish index of OCKHAM content from the command line. Enter a query along with the command to see results, a stream of XML.

=head1 BUGS

It is difficult, if not impossible, to do a freetext search because all the content is associated with fields. Thus you need specify a field in your query, i.e. title=barn or creator=morgan.

=cut

# define our modules
use SWISH::API;
use Ockham::Alert::Resource;
use Ockham::Alert::Config qw( SWISH_INDEX );

# define the index to search and open it
my $index = SWISH_INDEX;
my $swish = SWISH::API->new($index);

# do a search with the command line input
my $results = $swish->Query(@ARGV);

# check for hits
if ($results->Hits > 0) {

	# start the output
	binmode( STDOUT, ':utf8' );
	print qq(<?xml version="1.0" encoding="UTF-8"?>\n<results>\n);
	
	# process each result
	while (my $r = $results->NextResult) {
	
		# get the id
		my $resource = Ockham::Alert::Resource->retrieve($r->Property("swishdocpath"));
		
		# dump
		print "\t<record>\n";
		print "\t\t<id>"        . $resource->id()                   . "</id>\n";
		print "\t\t<added>"     . localtime($resource->created())   . "</added>\n";
		print "\t\t<harvested>" . localtime($resource->harvested()) . "</harvested>\n";
		print "\t\t<provider>"  . $resource->provider->name()       . "</provider>\n";
		print "\t\t<title>"      . $resource->field('title')         . "</title>\n";
		print "\t\t<identifier>" . $resource->field('identifier')    . "</identifier>\n";

		foreach ( $resource->descriptions ) {
		
			print "\t\t<description property='" . $_->property . "'>" . $_->value() . "</description>\n"
			
		}
	
		# clean up
		print "\t</record>\n";
		
	}
		
	# clean up
	print qq(</results>\n);

}

# done
exit;
