package Ockham::Alert::DB;

our $VERSION = '0.01';

use base qw( Class::DBI );
use Ockham::Alert::Config;
use Ockham::Alert::Resource;

__PACKAGE__->connection( 
    Ockham::Alert::Config::DB_DSN,
    Ockham::Alert::Config::DB_USERNAME,
    Ockham::Alert::Config::DB_PASSWORD,
    { AutoCommit => 1 }
);

=sub head1 purgeTo()

Pass in a DateTime object and you will purge all records that are older than
that time. The amount of records deleted is returned.

    my $date = DateTime->new( year => 1999, month => 5, day => 28 );
    my $records = Ockham::Alert::DB->purgeTo( $date );
    print "purged $records old records\n";

=cut

__PACKAGE__->set_sql( getOldImages => qq(
    SELECT id 
    FROM resource
    WHERE created < ?
) );

sub purgeTo {
    my ($class,$date) = @_;
    croak( "must supply DateTime object" ) if ref($date) ne 'DateTime';
    $sth = $class->sql_getOldImages();
    $sth->execute( $date->epoch() );
    my $iterator = Ockham::Alert::Resource->sth_to_objects( $sth );
    my $count = 0;
    while ( my $resource = $iterator->next() ) {
        $resource->delete();
        $count++;
    }
    $sth->finish();
    return( $count );
}

1;
