package Ockham::Alert::Indexer::Plucene;

use strict;
use warnings;

use Carp qw( croak );
use Plucene::Document;
use Plucene::Document::Field;
use Plucene::Index::Writer;
use Plucene::Analysis::SimpleAnalyzer;
use Ockham::Alert::Config qw( PLUCENE_INDEX );

my $writer;

sub addToIndex {
    return( 1 );
    my $resource = shift;
    $writer = _openWriter() if ! $writer;
    
    croak( "must pass in Ockham::Alert::Resource object" ) 
        if ! ref( $resource ) or ! $resource->isa( "Ockham::Alert::Resource" );
    my $doc = _createPluceneDocumentFromResource( $resource );
    if ( ! $doc ) { 
        warn( "attempted to index resource with no descriptions" );
        return( 1 );
    }
    $writer->add_document( $doc );
    return( 1 );
}

## _openWriter() creates an index writer 

sub _openWriter {
    return Plucene::Index::Writer->new(
        PLUCENE_INDEX,
        Plucene::Analysis::SimpleAnalyzer->new(), 
        -f PLUCENE_INDEX . '/segments' ? 0 : 1
    );
};

## pass in a Ockham::Alert::Resource object and get back a Plucene::Document
## suitable for indexing.

sub _createPluceneDocumentFromResource { 
    my $resource = shift;
    my $document = Plucene::Document->new();

    $document->add( 
        Plucene::Document::Field->Text( 
            'identifier.alertResource' => $resource->id()
        )
    );


    $document->add( 
        Plucene::Document::Field->Text( 
            'identifier.oai' => $resource->oai_id()
        )
    );

    $document->add( 
        Plucene::Document::Field->Text( 
            'date.created' => $resource->created()
        )
    );

    $document->add( 
        Plucene::Document::Field->Text( 
            contributor => $resource->provider->name()
        )
    );

    foreach my $desc ( $resource->descriptions() ) { 
        $document->add(
            Plucene::Document::Field->Text(
                $desc->property() => $desc->value()
            )
        );
    }

    return( $document );
}

1;
