package Ockham::Alert::Search::Plucene;

use Plucene::QueryParser;
use Plucene::Analysis::SimpleAnalyzer;
use Plucene::Search::IndexSearcher;
use Plucene::Search::HitCollector;
use Ockham::Alert::Resource;
use Ockham::Alert::Config qw( PLUCENE_INDEX );

my $parser = Plucene::QueryParser->new( {
    analyzer        => Plucene::Analysis::SimpleAnalyzer->new(),
    default         => 'text'
} );

my $searcher = Plucene::Search::IndexSearcher->new( 
    PLUCENE_INDEX
);

sub search { 
    my $queryString = shift;
    my $query = $parser->parse( $queryString );
    my @docs = ();
    my $collector = Plucene::Search::HitCollector->new(
        collect => sub {
            my ($self, $docId, $score)= @_;
            my $doc = $searcher->doc( $docId );
            push( @docs, $doc ) if $doc;
        }
    );
    $searcher->search_hc( $query, $collector );
    return( _docsToResources( \@docs ) );
}

sub _docsToResources {
    my $docs = shift;
    my @resources = ();
    foreach ( @$docs ) {
        my $id = $_->get( 'identifier.alertResource' )->string();;
        my $resource = Ockham::Alert::Resource->retrieve( id => $id );
        push( @resources, $resource );
    }
    return( @resources );
}

1;
