#!/usr/bin/perl

use strict;
use warnings;
use Test::More qw( no_plan );
use DateTime;

use_ok( 'Ockham::Alert::Resource' );
my $resourceId;

CREATE: { 

    my $provider = Ockham::Alert::Provider->find_or_create( {
        url         => 'http://memory.loc.gov/cgi-bin/oai2_0',
        type        => 'oai'
    } );
    isa_ok( $provider, 'Ockham::Alert::Provider' );

    my $r = Ockham::Alert::Resource->create( {
        oai_id      => 'foobar',
        provider    => $provider,
        created     => DateTime->now()
    } );
    isa_ok( $r, 'Ockham::Alert::Resource' );

    $r->add_to_descriptions( {
        property    => 'title',
        value       => 'Huckleberry Finn'
    } );
    $r->add_to_descriptions( {
        property    => 'creator',
        value       => 'Mark Twain'
    } );
    $r->add_to_descriptions( {
        property    => 'creator',
        value       => 'Samuel Clemens'
    } );
    $r->update();
    $resourceId = $r->id();
}

RETRIEVE: {
    my $r = Ockham::Alert::Resource->retrieve( $resourceId );
    isa_ok( $r, 'Ockham::Alert::Resource' );
    isa_ok( $r->created(), 'DateTime' );
    my @descriptions = $r->descriptions();
    is( @descriptions, 3, 'expected amount of descriptions' );
    map { isa_ok( $_, 'Ockham::Alert::Description' ) } @descriptions;
    my ( $gotTitle, $gotCreator1, $gotCreator2 ) = ( 0, 0, 0 );
    foreach ( @descriptions ) { 
        if ( $_->property() eq 'title' 
            and $_->value() eq 'Huckleberry Finn' ) {
            $gotTitle = 1;
        }
        if ( $_->property() eq 'creator' 
            and $_->value() eq 'Mark Twain' ) { 
            $gotCreator1 = 1;
        }
        if ( $_->property() eq 'creator' 
            and $_->value() eq 'Samuel Clemens' ) {
            $gotCreator2 = 1;
        }
    }
    ok( $gotTitle, 'retrieved title' );
    ok( $gotCreator1, 'retrieved first creator' );
    ok( $gotCreator2, 'retrieved second creator' );
}

UPDATE: { 
    my $r = Ockham::Alert::Resource->retrieve( $resourceId );
    isa_ok( $r, 'Ockham::Alert::Resource' );
}

DELETE: {
    my $r = Ockham::Alert::Resource->retrieve( $resourceId );
    isa_ok( $r, 'Ockham::Alert::Resource' );
    ok( $r->delete(), 'delete()' );
}
