#!/usr/bin/perl

use strict;
use warnings;
use Test::More qw( no_plan );

## this test will harvest a known OAI record from LC
## and add create an Ockham::Alert::Resource based on it

use_ok( 'Ockham::Alert::Resource' );
use_ok( 'Ockham::Alert::Provider' );

my $provider = Ockham::Alert::Provider->find_or_create( {
    url => 'http://memory.loc.gov/cgi-bin/oai2_0'
} );

my $harvester = $provider->harvester();
isa_ok( $harvester, 'Net::OAI::Harvester' );

## get a known record (this may have to change over time)
my $rec = $harvester->getRecord( 
    identifier          => 'oai:lcoa1.loc.gov:loc.gmd/g3764s.pm003250',
    metadataPrefix      => 'oai_dc' 
);

## create Ockham resource from OAI record
my $resource = Ockham::Alert::Resource->createFromOAIRecord( 
    record      => $rec,
    provider    => $provider
);
isa_ok( $resource, 'Ockham::Alert::Resource' );

my @descriptions = $resource->descriptions();
map { isa_ok( $_, 'Ockham::Alert::Description' ) } @descriptions;
is( 
    $resource->field( 'title' ), 
    'View of Springfield, Mass. 1875.', 
    'title looks good' 
);

## delete
$resource->delete();

